@@ -41,26 +41,6 @@
 #include "synchronization/syncserviceaddin.hpp"
 
 
-#if 1
-
-// HACK to make sure we link the modules needed only for addins
-#include "base/inifile.hpp"
-#include "sharp/fileinfo.hpp"
-#include "sharp/streamwriter.hpp"
-#include "sharp/xsltransform.hpp"
-#include "sharp/xsltargumentlist.hpp"
-
-bool links[] = {
-  base::IniFileLink_,
-  sharp::FileInfoLink_,
-  sharp::StreamWriterLink_,
-  sharp::XslTransformLink_,
-  sharp::XsltArgumentListLink_,
-  false
-};
-
-
-#endif
 
 
 namespace gnote {
@@ -312,6 +292,16 @@ namespace gnote {
     return 0;
   }
 
+  sync::SyncServiceAddin *AddinManager::get_sync_service_addin(const std::string & id) const
+  {
+    const IdSyncServiceAddinMap::const_iterator iter = m_sync_service_addins.find(id);
+    if(iter != m_sync_service_addins.end()) {
+      return iter->second;
+    }
+
+    return NULL;
+  }
+
   void AddinManager::get_preference_tab_addins(std::list<PreferenceTabAddin *> &l) const
   {
     sharp::map_get_values(m_pref_tab_addins, l);
@@ -342,6 +332,26 @@ namespace gnote {
     }
   }
 
+  void AddinManager::initialize_sync_service_addins() const
+  {
+    for(IdSyncServiceAddinMap::const_iterator iter = m_sync_service_addins.begin();
+        iter != m_sync_service_addins.end(); ++iter) {
+      sync::SyncServiceAddin *addin = NULL;
+      try {
+        addin = iter->second;
+        const sharp::DynamicModule *dmod = m_module_manager.get_module(iter->first);
+        if(!dmod || dmod->is_enabled()) {
+          addin->initialize();
+        }
+      }
+      catch(std::exception & e) {
+        DBG_OUT("Error calling %s.initialize (): %s", addin->id().c_str(), e.what());
+
+        // TODO: Call something like AddinManager.Disable (addin)
+      }
+    }
+  }
+
   void AddinManager::shutdown_application_addins() const
   {
     for(AppAddinMap::const_iterator iter = m_app_addins.begin();
