@@ -138,6 +138,15 @@ namespace gnote {
   }
 
 
+  void Gnote::on_window_removed(Gtk::Window *window)
+  {
+    // Do not remove last window if background or status icon mode
+    if(windowed() || get_windows().size() > 1) {
+      Gtk::Application::on_window_removed(window);
+    }
+  }
+
+
   void Gnote::common_init()
   {
     std::string note_path = get_note_path(cmd_line.note_path());
